==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Containers/AmazonElasticContainerServiceService.md <==
# AmazonElasticContainerServiceService


```text
aws-20210730/Resource/Containers/AmazonElasticContainerServiceService
```

```text
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')
```



| Illustration | AmazonElasticContainerServiceService | AmazonElasticContainerServiceServiceCard | AmazonElasticContainerServiceServiceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceService.png) | ![illustration for AmazonElasticContainerServiceService](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceService.Local.png) | ![illustration for AmazonElasticContainerServiceServiceCard](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceServiceCard.Local.png) | ![illustration for AmazonElasticContainerServiceServiceGroup](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceServiceGroup.Local.png) |




## AmazonElasticContainerServiceService

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceService
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceService('AmazonElasticContainerServiceService', 'Amazon Elastic Container Service Service', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceService
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceService('AmazonElasticContainerServiceService', 'Amazon Elastic Container Service Service', 'an optional tech label')
@enduml
```

## AmazonElasticContainerServiceServiceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceCard('AmazonElasticContainerServiceServiceCard', 'Amazon Elastic Container Service Service Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceCard('AmazonElasticContainerServiceServiceCard', 'Amazon Elastic Container Service Service Card', 'an optional description')
@enduml
```

## AmazonElasticContainerServiceServiceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceGroup('AmazonElasticContainerServiceServiceGroup', 'Amazon Elastic Container Service Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceGroup('AmazonElasticContainerServiceServiceGroup', 'Amazon Elastic Container Service Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Containers/AmazonElasticContainerServiceService.md <==
# AmazonElasticContainerServiceService


```text
aws-20210730/Resource/Containers/AmazonElasticContainerServiceService
```

```text
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')
```



| Illustration | AmazonElasticContainerServiceService | AmazonElasticContainerServiceServiceCard | AmazonElasticContainerServiceServiceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceService.png) | ![illustration for AmazonElasticContainerServiceService](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceService.Local.png) | ![illustration for AmazonElasticContainerServiceServiceCard](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceServiceCard.Local.png) | ![illustration for AmazonElasticContainerServiceServiceGroup](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceServiceGroup.Local.png) |




## AmazonElasticContainerServiceService

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceService
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceService('AmazonElasticContainerServiceService', 'Amazon Elastic Container Service Service', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceService
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceService('AmazonElasticContainerServiceService', 'Amazon Elastic Container Service Service', 'an optional tech label')
@enduml
```

## AmazonElasticContainerServiceServiceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceCard('AmazonElasticContainerServiceServiceCard', 'Amazon Elastic Container Service Service Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceCard('AmazonElasticContainerServiceServiceCard', 'Amazon Elastic Container Service Service Card', 'an optional description')
@enduml
```

## AmazonElasticContainerServiceServiceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceGroup('AmazonElasticContainerServiceServiceGroup', 'Amazon Elastic Container Service Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceServiceGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceService')

' renders the element
AmazonElasticContainerServiceServiceGroup('AmazonElasticContainerServiceServiceGroup', 'Amazon Elastic Container Service Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
